# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegionGrowingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkConfidenceConnectedImageFilterPython
else:
    import _itkConfidenceConnectedImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkIndexPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkOffsetPython
import itk.itkVariableLengthVectorPython
import itk.stdcomplexPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkConfidenceConnectedImageFilterIF2ISS2_New():
    return itkConfidenceConnectedImageFilterIF2ISS2.New()

class itkConfidenceConnectedImageFilterIF2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2ISS2):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIF2ISS2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIF2ISS2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIF2ISS2

        Create a new object of the class itkConfidenceConnectedImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIF2ISS2 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2ISS2_swigregister(itkConfidenceConnectedImageFilterIF2ISS2)

def itkConfidenceConnectedImageFilterIF2IUC2_New():
    return itkConfidenceConnectedImageFilterIF2IUC2.New()

class itkConfidenceConnectedImageFilterIF2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IUC2):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIF2IUC2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIF2IUC2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIF2IUC2

        Create a new object of the class itkConfidenceConnectedImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIF2IUC2 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF2IUC2_swigregister(itkConfidenceConnectedImageFilterIF2IUC2)

def itkConfidenceConnectedImageFilterIF3ISS3_New():
    return itkConfidenceConnectedImageFilterIF3ISS3.New()

class itkConfidenceConnectedImageFilterIF3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3ISS3):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIF3ISS3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIF3ISS3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIF3ISS3

        Create a new object of the class itkConfidenceConnectedImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIF3ISS3 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3ISS3_swigregister(itkConfidenceConnectedImageFilterIF3ISS3)

def itkConfidenceConnectedImageFilterIF3IUC3_New():
    return itkConfidenceConnectedImageFilterIF3IUC3.New()

class itkConfidenceConnectedImageFilterIF3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IUC3):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIF3IUC3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIF3IUC3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIF3IUC3

        Create a new object of the class itkConfidenceConnectedImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIF3IUC3 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIF3IUC3_swigregister(itkConfidenceConnectedImageFilterIF3IUC3)

def itkConfidenceConnectedImageFilterISS2ISS2_New():
    return itkConfidenceConnectedImageFilterISS2ISS2.New()

class itkConfidenceConnectedImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterISS2ISS2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterISS2ISS2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterISS2ISS2

        Create a new object of the class itkConfidenceConnectedImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterISS2ISS2 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2ISS2_swigregister(itkConfidenceConnectedImageFilterISS2ISS2)

def itkConfidenceConnectedImageFilterISS2IUC2_New():
    return itkConfidenceConnectedImageFilterISS2IUC2.New()

class itkConfidenceConnectedImageFilterISS2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2IUC2):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterISS2IUC2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterISS2IUC2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterISS2IUC2

        Create a new object of the class itkConfidenceConnectedImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterISS2IUC2 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS2IUC2_swigregister(itkConfidenceConnectedImageFilterISS2IUC2)

def itkConfidenceConnectedImageFilterISS3ISS3_New():
    return itkConfidenceConnectedImageFilterISS3ISS3.New()

class itkConfidenceConnectedImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterISS3ISS3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterISS3ISS3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterISS3ISS3

        Create a new object of the class itkConfidenceConnectedImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterISS3ISS3 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3ISS3_swigregister(itkConfidenceConnectedImageFilterISS3ISS3)

def itkConfidenceConnectedImageFilterISS3IUC3_New():
    return itkConfidenceConnectedImageFilterISS3IUC3.New()

class itkConfidenceConnectedImageFilterISS3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3IUC3):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterISS3IUC3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterISS3IUC3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterISS3IUC3

        Create a new object of the class itkConfidenceConnectedImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterISS3IUC3 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterISS3IUC3_swigregister(itkConfidenceConnectedImageFilterISS3IUC3)

def itkConfidenceConnectedImageFilterIUC2ISS2_New():
    return itkConfidenceConnectedImageFilterIUC2ISS2.New()

class itkConfidenceConnectedImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2ISS2):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIUC2ISS2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIUC2ISS2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIUC2ISS2

        Create a new object of the class itkConfidenceConnectedImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIUC2ISS2 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2ISS2_swigregister(itkConfidenceConnectedImageFilterIUC2ISS2)

def itkConfidenceConnectedImageFilterIUC2IUC2_New():
    return itkConfidenceConnectedImageFilterIUC2IUC2.New()

class itkConfidenceConnectedImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIUC2IUC2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIUC2IUC2_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIUC2IUC2

        Create a new object of the class itkConfidenceConnectedImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIUC2IUC2 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC2IUC2_swigregister(itkConfidenceConnectedImageFilterIUC2IUC2)

def itkConfidenceConnectedImageFilterIUC3ISS3_New():
    return itkConfidenceConnectedImageFilterIUC3ISS3.New()

class itkConfidenceConnectedImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3ISS3):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIUC3ISS3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIUC3ISS3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIUC3ISS3

        Create a new object of the class itkConfidenceConnectedImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIUC3ISS3 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3ISS3_swigregister(itkConfidenceConnectedImageFilterIUC3ISS3)

def itkConfidenceConnectedImageFilterIUC3IUC3_New():
    return itkConfidenceConnectedImageFilterIUC3IUC3.New()

class itkConfidenceConnectedImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkConfidenceConnectedImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConfidenceConnectedImageFilterIUC3IUC3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConfidenceConnectedImageFilterIUC3IUC3_Pointer"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_SetSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_ClearSeeds(self)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_AddSeed(self, seed)

    def SetMultiplier(self, _arg):
        r"""
        SetMultiplier(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_SetMultiplier(self, _arg)

    def GetMultiplier(self):
        r"""GetMultiplier(self) -> double"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetMultiplier(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetNumberOfIterations(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetReplaceValue(self)

    def SetInitialNeighborhoodRadius(self, _arg):
        r"""
        SetInitialNeighborhoodRadius(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_SetInitialNeighborhoodRadius(self, _arg)

    def GetInitialNeighborhoodRadius(self):
        r"""GetInitialNeighborhoodRadius(self) -> unsigned int const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetInitialNeighborhoodRadius(self)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetMean(self)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetVariance(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_GetSeeds(self)
    InputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    OutputHasNumericTraitsCheck = _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkConfidenceConnectedImageFilterPython.delete_itkConfidenceConnectedImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConfidenceConnectedImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConfidenceConnectedImageFilterIUC3IUC3

        Create a new object of the class itkConfidenceConnectedImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConfidenceConnectedImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConfidenceConnectedImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConfidenceConnectedImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConfidenceConnectedImageFilterIUC3IUC3 in _itkConfidenceConnectedImageFilterPython:
_itkConfidenceConnectedImageFilterPython.itkConfidenceConnectedImageFilterIUC3IUC3_swigregister(itkConfidenceConnectedImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def confidence_connected_image_filter(*args: itkt.ImageLike,  seed: Sequence[int]=..., multiplier: float=..., number_of_iterations: int=..., replace_value: int=..., initial_neighborhood_radius: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ConfidenceConnectedImageFilter"""
    import itk

    kwarg_typehints = { 'seed':seed,'multiplier':multiplier,'number_of_iterations':number_of_iterations,'replace_value':replace_value,'initial_neighborhood_radius':initial_neighborhood_radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ConfidenceConnectedImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def confidence_connected_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKRegionGrowing.ConfidenceConnectedImageFilter
    confidence_connected_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    confidence_connected_image_filter.__doc__ = filter_object.__doc__



